.. _`pip search`:

==========
pip search
==========

.. contents::


Usage
=====

.. pip-command-usage:: search


Description
===========

.. pip-command-description:: search


Options
=======

.. pip-command-options:: search


Examples
========

#. Search for "peppercorn"

    ::

     $ pip search peppercorn
     pepperedform    - Helpers for using peppercorn with formprocess.
     peppercorn      - A library for converting a token stream into [...]
